File Browser Command

Terminal Command to open the File Browser on your platform.

Template TiddlyWiki Path

The path location of the blank TiddlyWiki file used to create new TiddlyWikis.

GO The GO button opens the TiddlyWiki file in the twpy Editor.

IN The IN button reveals the TiddlyWiki file in the native system File Browser (The terminal command for File Browser must be set in 'twpy Settings').

RM The RM button (must be double-clicked) removes the TiddlyWiki reference from the twpy Manager (underlying TiddlyWiki file is untouched).

~/.twpy is the location of the folder for your twpy workspace. If you want to restore the default workspace/settings, remove workspacelist.html from this folder.

twpym is the terminal command for starting the twpy TiddlyWiki Manager. --verbose is an option. You can open TiddlyWiki files in the Editor from the Manager.

twpye is the terminal command for starting the twpy TiddlyWiki Editor. Requires --file your-tiddly-wiki-path.html option. --verbose is also an option.

TiddlyWiki is a work of genius by Jeremy Ruston, who has come up with almost certainly the greatest notetaking application ever. Ingenious self-contained self-replicating single-file design, the most future-proof rich text format, html, that may be readable for centuries when other formats are forgotten.

twpy was created by The TWPY Organization to be an extremely minimalist, cognitively and computationally efficient editor for TiddlyWiki files. twpy was designed by and for one who has spent hours of every day for years in TiddlyWiki - the power-users and super-fans, the people who can't live without it. In the early days, browser plugins got the job done, although occasionally had saving problems. The death of the plugins forced everyone to migrate to Tiddly Desktop, a rather large program (170 MB) that has all kinds of dependencies on even more bloated software libraries (NW.js, 190 MB). All these complex parts do not always play well on every system.

twpy changes the game with only a few kilobytes of high-level scripting language, and miraculously, only 1 dependency: pywebview, which itself only has 1 dependency. No local or remote server is required. In the spirit of TiddlyWiki, twpy manager uses a html interface inside of a pywebview, opening up opportunities for all kinds of skins and mods.

twpy was written in Python to take advantage of the robust and reliable pip package manager, possibly the best in the world, even better than ubuntu's native package manger apt. While the Python language leaves much to be desired compared to more syntactically powerful metaprogramming languages like Ruby, the pip package manager works when all others fail.